@@ -56,7 +56,6 @@
 #include "nautilus-window-private.h"
 #include "nautilus-window-manage-views.h"
 #include <unistd.h>
-#include <errno.h>
 #include <libxml/xmlsave.h>
 #include <glib/gstdio.h>
 #include <glib/gi18n.h>
@@ -589,9 +588,8 @@ static void
 do_upgrades_once (NautilusApplication *application,
 		  gboolean no_desktop)
 {
-	char *metafile_dir, *updated, *nautilus_dir, *xdg_dir;
-	const gchar *message;
-	int fd, res;
+	char *metafile_dir, *updated;
+	int fd;
 
 	if (!no_desktop) {
 		mark_desktop_files_trusted ();
@@ -611,35 +609,6 @@ do_upgrades_once (NautilusApplication *application,
 		g_free (updated);
 	}
 	g_free (metafile_dir);
-
-	nautilus_dir = g_build_filename (g_get_home_dir (),
-					 ".nautilus", NULL);
-	xdg_dir = nautilus_get_user_directory ();
-	if (g_file_test (nautilus_dir, G_FILE_TEST_IS_DIR)) {
-		/* test if we already attempted to migrate first */
-		updated = g_build_filename (nautilus_dir, "DEPRECATED-DIRECTORY", NULL);
-		message = _("Nautilus 2.32 deprecated this directory and tried migrating "
-			    "this configuration to ~/.config/nautilus");
-		if (!g_file_test (updated, G_FILE_TEST_EXISTS)) {
-			/* rename() works fine if the destination directory is
-			 * empty.
-			 */
-			res = g_rename (nautilus_dir, xdg_dir);
-
-			if (res == -1) {
-				fd = g_creat (updated, 0600);
-				if (fd != -1) {
-					res = write (fd, message, strlen (message));
-					close (fd);
-				}
-			}
-		}
-
-		g_free (updated);
-	}
-
-	g_free (nautilus_dir);
-	g_free (xdg_dir);
 }
 
 static void
@@ -904,6 +873,7 @@ nautilus_application_startup (NautilusApplication *application,
 						  &error,
 						  "application-id", "org.gnome.Nautilus",
 						  "default-quit", FALSE,
+						  "argv", g_variant_new_bytestring_array (NULL, 0),
 						  NULL);
 	g_assert (error == NULL);
 	is_remote = g_application_is_remote (application->unique_app);
@@ -1152,6 +1122,17 @@ nautilus_application_close_all_navigation_windows (void)
 	GList *l;
 	
 	list_copy = g_list_copy (nautilus_application_window_list);
+	/* First hide all window to get the feeling of quick response */
+	for (l = list_copy; l != NULL; l = l->next) {
+		NautilusWindow *window;
+		
+		window = NAUTILUS_WINDOW (l->data);
+
+		if (NAUTILUS_IS_NAVIGATION_WINDOW (window)) {
+			gtk_widget_hide (GTK_WIDGET (window));
+		}
+	}
+
 	for (l = list_copy; l != NULL; l = l->next) {
 		NautilusWindow *window;
 		
@@ -1259,6 +1240,17 @@ nautilus_application_close_all_spatial_windows (void)
 	GList *l;
 	
 	list_copy = g_list_copy (nautilus_application_spatial_window_list);
+	/* First hide all window to get the feeling of quick response */
+	for (l = list_copy; l != NULL; l = l->next) {
+		NautilusWindow *window;
+		
+		window = NAUTILUS_WINDOW (l->data);
+		
+		if (NAUTILUS_IS_SPATIAL_WINDOW (window)) {
+			gtk_widget_hide (GTK_WIDGET (window));
+		}
+	}
+
 	for (l = list_copy; l != NULL; l = l->next) {
 		NautilusWindow *window;
 		
